@@ -1,4 +1,4 @@
-package Pcore::Service::Nginx v0.2.2;
+package Pcore::Service::Nginx v0.3.0;
 
 use Pcore -dist, -class;
 
@@ -59,6 +59,11 @@ sub run ($self) {
     # generate conf.nginx
     P->file->write_text( $self->conf_dir . '/conf.nginx', { mode => q[rw-r--r--] }, P->tmpl( type => 'text' )->render( 'nginx/conf.nginx', $params ) );
 
+    # create and prepare unix socket dir
+    P->file->mkdir('/var/run/nginx') if !-d '/var/run/nginx';
+
+    # chown $uid, $uid, '/var/run/nginx' or die;
+
     $self->{proc} = P->sys->run_proc( [ $self->{nginx_bin}, '-c', $self->conf_dir . '/conf.nginx' ] );
 
     return;
